align

package
v0.7.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Overview

Package align runs the upstream fieldalignment analyzer over a Target and returns the suggested struct reorderings as data (no rendering).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Aligner

type Aligner struct{}

Aligner implements common.Aligner.

func New

func New() *Aligner

New returns an Aligner.

func (*Aligner) Findings

func (a *Aligner) Findings(t common.Target, opts common.Options) ([]common.Finding, error)

Findings runs the analyzer over t and returns one Finding per suggested reordering, controlled by opts.

Jump to