Documentation
¶
Index ¶
- type Aligner
- type Aligner_Expecter
- type Aligner_Findings_Call
- func (_c *Aligner_Findings_Call) Return(_a0 []common.Finding, _a1 error) *Aligner_Findings_Call
- func (_c *Aligner_Findings_Call) Run(run func(t common.Target, opts common.Options)) *Aligner_Findings_Call
- func (_c *Aligner_Findings_Call) RunAndReturn(run func(common.Target, common.Options) ([]common.Finding, error)) *Aligner_Findings_Call
- type Inspector
- type Inspector_Expecter
- type Inspector_Layouts_Call
- func (_c *Inspector_Layouts_Call) Return(_a0 []common.Layout) *Inspector_Layouts_Call
- func (_c *Inspector_Layouts_Call) Run(run func(t common.Target, opts common.Options)) *Inspector_Layouts_Call
- func (_c *Inspector_Layouts_Call) RunAndReturn(run func(common.Target, common.Options) []common.Layout) *Inspector_Layouts_Call
- type Loader
- type Loader_Expecter
- type Loader_Load_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Aligner ¶
Aligner is an autogenerated mock type for the Aligner type
func NewAligner ¶
NewAligner creates a new instance of Aligner. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Aligner) EXPECT ¶
func (_m *Aligner) EXPECT() *Aligner_Expecter
type Aligner_Expecter ¶
type Aligner_Expecter struct {
// contains filtered or unexported fields
}
func (*Aligner_Expecter) Findings ¶
func (_e *Aligner_Expecter) Findings(t interface{}, opts interface{}) *Aligner_Findings_Call
Findings is a helper method to define mock.On call
- t common.Target
- opts common.Options
type Aligner_Findings_Call ¶
Aligner_Findings_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Findings'
func (*Aligner_Findings_Call) Return ¶
func (_c *Aligner_Findings_Call) Return(_a0 []common.Finding, _a1 error) *Aligner_Findings_Call
func (*Aligner_Findings_Call) Run ¶
func (_c *Aligner_Findings_Call) Run(run func(t common.Target, opts common.Options)) *Aligner_Findings_Call
func (*Aligner_Findings_Call) RunAndReturn ¶
func (_c *Aligner_Findings_Call) RunAndReturn(run func(common.Target, common.Options) ([]common.Finding, error)) *Aligner_Findings_Call
type Inspector ¶
Inspector is an autogenerated mock type for the Inspector type
func NewInspector ¶
NewInspector creates a new instance of Inspector. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Inspector) EXPECT ¶
func (_m *Inspector) EXPECT() *Inspector_Expecter
type Inspector_Expecter ¶
type Inspector_Expecter struct {
// contains filtered or unexported fields
}
func (*Inspector_Expecter) Layouts ¶
func (_e *Inspector_Expecter) Layouts(t interface{}, opts interface{}) *Inspector_Layouts_Call
Layouts is a helper method to define mock.On call
- t common.Target
- opts common.Options
type Inspector_Layouts_Call ¶
Inspector_Layouts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Layouts'
func (*Inspector_Layouts_Call) Return ¶
func (_c *Inspector_Layouts_Call) Return(_a0 []common.Layout) *Inspector_Layouts_Call
func (*Inspector_Layouts_Call) Run ¶
func (_c *Inspector_Layouts_Call) Run(run func(t common.Target, opts common.Options)) *Inspector_Layouts_Call
func (*Inspector_Layouts_Call) RunAndReturn ¶
func (_c *Inspector_Layouts_Call) RunAndReturn(run func(common.Target, common.Options) []common.Layout) *Inspector_Layouts_Call
type Loader ¶
Loader is an autogenerated mock type for the Loader type
func NewLoader ¶
NewLoader creates a new instance of Loader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Loader) EXPECT ¶
func (_m *Loader) EXPECT() *Loader_Expecter
type Loader_Expecter ¶
type Loader_Expecter struct {
// contains filtered or unexported fields
}
func (*Loader_Expecter) Load ¶
func (_e *Loader_Expecter) Load(patterns ...interface{}) *Loader_Load_Call
Load is a helper method to define mock.On call
- patterns ...string
type Loader_Load_Call ¶
Loader_Load_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Load'
func (*Loader_Load_Call) Return ¶
func (_c *Loader_Load_Call) Return(_a0 []common.Target, _a1 error) *Loader_Load_Call
func (*Loader_Load_Call) Run ¶
func (_c *Loader_Load_Call) Run(run func(patterns ...string)) *Loader_Load_Call
func (*Loader_Load_Call) RunAndReturn ¶
func (_c *Loader_Load_Call) RunAndReturn(run func(...string) ([]common.Target, error)) *Loader_Load_Call