mocks

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Aligner

type Aligner struct {
	mock.Mock
}

Aligner is an autogenerated mock type for the Aligner type

func NewAligner

func NewAligner(t interface {
	mock.TestingT
	Cleanup(func())
}) *Aligner

NewAligner creates a new instance of Aligner. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Aligner) EXPECT

func (_m *Aligner) EXPECT() *Aligner_Expecter

func (*Aligner) Findings

func (_m *Aligner) Findings(t common.Target, patterns []string, keepTags bool) ([]common.Finding, error)

Findings provides a mock function with given fields: t, patterns, keepTags

type Aligner_Expecter

type Aligner_Expecter struct {
	// contains filtered or unexported fields
}

func (*Aligner_Expecter) Findings

func (_e *Aligner_Expecter) Findings(t interface{}, patterns interface{}, keepTags interface{}) *Aligner_Findings_Call

Findings is a helper method to define mock.On call

  • t common.Target
  • patterns []string
  • keepTags bool

type Aligner_Findings_Call

type Aligner_Findings_Call struct {
	*mock.Call
}

Aligner_Findings_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Findings'

func (*Aligner_Findings_Call) Return

func (*Aligner_Findings_Call) Run

func (_c *Aligner_Findings_Call) Run(run func(t common.Target, patterns []string, keepTags bool)) *Aligner_Findings_Call

func (*Aligner_Findings_Call) RunAndReturn

func (_c *Aligner_Findings_Call) RunAndReturn(run func(common.Target, []string, bool) ([]common.Finding, error)) *Aligner_Findings_Call

type Inspector

type Inspector struct {
	mock.Mock
}

Inspector is an autogenerated mock type for the Inspector type

func NewInspector

func NewInspector(t interface {
	mock.TestingT
	Cleanup(func())
}) *Inspector

NewInspector creates a new instance of Inspector. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Inspector) EXPECT

func (_m *Inspector) EXPECT() *Inspector_Expecter

func (*Inspector) Layouts

func (_m *Inspector) Layouts(t common.Target, patterns []string) []common.Layout

Layouts provides a mock function with given fields: t, patterns

type Inspector_Expecter

type Inspector_Expecter struct {
	// contains filtered or unexported fields
}

func (*Inspector_Expecter) Layouts

func (_e *Inspector_Expecter) Layouts(t interface{}, patterns interface{}) *Inspector_Layouts_Call

Layouts is a helper method to define mock.On call

  • t common.Target
  • patterns []string

type Inspector_Layouts_Call

type Inspector_Layouts_Call struct {
	*mock.Call
}

Inspector_Layouts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Layouts'

func (*Inspector_Layouts_Call) Return

func (*Inspector_Layouts_Call) Run

func (_c *Inspector_Layouts_Call) Run(run func(t common.Target, patterns []string)) *Inspector_Layouts_Call

func (*Inspector_Layouts_Call) RunAndReturn

type Loader

type Loader struct {
	mock.Mock
}

Loader is an autogenerated mock type for the Loader type

func NewLoader

func NewLoader(t interface {
	mock.TestingT
	Cleanup(func())
}) *Loader

NewLoader creates a new instance of Loader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Loader) EXPECT

func (_m *Loader) EXPECT() *Loader_Expecter

func (*Loader) Load

func (_m *Loader) Load(patterns ...string) ([]common.Target, error)

Load provides a mock function with given fields: patterns

type Loader_Expecter

type Loader_Expecter struct {
	// contains filtered or unexported fields
}

func (*Loader_Expecter) Load

func (_e *Loader_Expecter) Load(patterns ...interface{}) *Loader_Load_Call

Load is a helper method to define mock.On call

  • patterns ...string

type Loader_Load_Call

type Loader_Load_Call struct {
	*mock.Call
}

Loader_Load_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Load'

func (*Loader_Load_Call) Return

func (_c *Loader_Load_Call) Return(_a0 []common.Target, _a1 error) *Loader_Load_Call

func (*Loader_Load_Call) Run

func (_c *Loader_Load_Call) Run(run func(patterns ...string)) *Loader_Load_Call

func (*Loader_Load_Call) RunAndReturn

func (_c *Loader_Load_Call) RunAndReturn(run func(...string) ([]common.Target, error)) *Loader_Load_Call

Jump to