Documentation
¶
Overview ¶
Package structfilter holds predicates for excluding structs from analysis: generated files and cache-line-padded structs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HasCacheLinePad ¶
HasCacheLinePad reports whether st has a field of type golang.org/x/sys/cpu.CacheLinePad (the false-sharing guard).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.